@@ -15,6 +15,8 @@
 #define ICON_THEME_KEY "X-GNOME-Metatheme/IconTheme"
 #define SOUND_THEME_KEY "X-GNOME-Metatheme/SoundTheme"
 #define APPLICATION_FONT_KEY "X-GNOME-Metatheme/ApplicationFont"
+#define DESKTOP_FONT_KEY "X-GNOME-Metatheme/DesktopFont"
+#define MONOSPACE_FONT_KEY "X-GNOME-Metatheme/MonospaceFont"
 #define BACKGROUND_IMAGE_KEY "X-GNOME-Metatheme/BackgroundImage"
 
 /* Terminology used in this lib:
@@ -369,6 +371,14 @@ gnome_theme_read_meta_theme (GnomeVFSURI *meta_theme_uri)
   str = gnome_desktop_item_get_string (meta_theme_ditem, APPLICATION_FONT_KEY);
   if (str != NULL)
     meta_theme_info->application_font = g_strdup (str);
+
+  str = gnome_desktop_item_get_string (meta_theme_ditem, DESKTOP_FONT_KEY);
+  if (str != NULL)
+    meta_theme_info->desktop_font = g_strdup (str);
+
+  str = gnome_desktop_item_get_string (meta_theme_ditem, MONOSPACE_FONT_KEY);
+  if (str != NULL)
+    meta_theme_info->monospace_font = g_strdup (str);
     
   str = gnome_desktop_item_get_string (meta_theme_ditem, BACKGROUND_IMAGE_KEY);
   if (str != NULL)
@@ -1467,6 +1477,8 @@ gnome_theme_meta_info_free (GnomeThemeMetaInfo *meta_theme_info)
   g_free (meta_theme_info->name);
   g_free (meta_theme_info->comment);
   g_free (meta_theme_info->application_font);
+  g_free (meta_theme_info->desktop_font);
+  g_free (meta_theme_info->monospace_font);
   g_free (meta_theme_info->background_image);
   g_free (meta_theme_info->gtk_theme_name);
   g_free (meta_theme_info->icon_theme_name);
@@ -1489,6 +1501,8 @@ gnome_theme_meta_info_print (GnomeThemeMetaInfo *meta_theme_info)
   g_print ("sawfish_theme_name: %s\n", meta_theme_info->sawfish_theme_name);
   g_print ("sound_theme_name: %s\n", meta_theme_info->sound_theme_name);
   g_print ("application_font: %s\n", meta_theme_info->application_font);
+  g_print ("desktop_font: %s\n", meta_theme_info->desktop_font);
+  g_print ("monospace_font: %s\n", meta_theme_info->monospace_font);
   g_print ("background_image: %s\n", meta_theme_info->background_image);
 }
 
@@ -1571,6 +1585,12 @@ gnome_theme_meta_info_compare (GnomeThemeMetaInfo *a,
   
   cmp = safe_strcmp (a->application_font, b->application_font);
   if (cmp != 0) return cmp;
+
+  cmp = safe_strcmp (a->desktop_font, b->desktop_font);
+  if (cmp != 0) return cmp;
+
+  cmp = safe_strcmp (a->monospace_font, b->monospace_font);
+  if (cmp != 0) return cmp;
   
   cmp = safe_strcmp (a->background_image, b->background_image);
   return cmp;
